==> django_jp_birthday-0.4.0.tar.gz: django_jp_birthday-0.4.0/HISTORY.md <==
# HISTORY

## [v0.3.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.3.0) (2022-02-07)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.2.0...v0.3.0)

## [v0.2.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.2.0) (2022-02-07)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.5...v0.2.0)

**Closed issues:**

- Initial Update [\#30](https://github.com/shimakaze-git/django-jp-birthday/issues/30)

**Merged pull requests:**

- v0.2.0 [\#40](https://github.com/shimakaze-git/django-jp-birthday/pull/40) ([github-actions[bot]](https://github.com/apps/github-actions))
- Versionを0.2にアップロード. [\#39](https://github.com/shimakaze-git/django-jp-birthday/pull/39) ([shimakaze-git](https://github.com/shimakaze-git))
- v0.1.5 [\#37](https://github.com/shimakaze-git/django-jp-birthday/pull/37) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: git pushの処理を追加. [\#36](https://github.com/shimakaze-git/django-jp-birthday/pull/36) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.5](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.5) (2022-01-29)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

- v0.1.5 [\#35](https://github.com/shimakaze-git/django-jp-birthday/pull/35) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master. [\#34](https://github.com/shimakaze-git/django-jp-birthday/pull/34) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.4](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.4) (2022-01-29)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

- v0.1.4 [\#33](https://github.com/shimakaze-git/django-jp-birthday/pull/33) ([github-actions[bot]](https://github.com/apps/github-actions))
- 0.1.4にバージョンアップ. [\#32](https://github.com/shimakaze-git/django-jp-birthday/pull/32) ([shimakaze-git](https://github.com/shimakaze-git))
- Config file for pyup.io [\#31](https://github.com/shimakaze-git/django-jp-birthday/pull/31) ([pyup-bot](https://github.com/pyup-bot))
- v0.1.3 [\#29](https://github.com/shimakaze-git/django-jp-birthday/pull/29) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: templateを修正していく. [\#28](https://github.com/shimakaze-git/django-jp-birthday/pull/28) ([shimakaze-git](https://github.com/shimakaze-git))
- \[v0.1.3\] \(2022-01-29\) [\#27](https://github.com/shimakaze-git/django-jp-birthday/pull/27) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: add HISTORY.rstを削除していく. [\#26](https://github.com/shimakaze-git/django-jp-birthday/pull/26) ([shimakaze-git](https://github.com/shimakaze-git))
- \[v0.1.3\] \(2022-01-29\) [\#25](https://github.com/shimakaze-git/django-jp-birthday/pull/25) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master [\#24](https://github.com/shimakaze-git/django-jp-birthday/pull/24) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.3](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.3) (2022-01-28)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/515815cbe454ff9b0caf506429079c329f91a11e...v0.1.3)

**Merged pull requests:**

- v0.1.3 [\#23](https://github.com/shimakaze-git/django-jp-birthday/pull/23) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master. [\#22](https://github.com/shimakaze-git/django-jp-birthday/pull/22) ([shimakaze-git](https://github.com/shimakaze-git))
- v0.1.3 [\#21](https://github.com/shimakaze-git/django-jp-birthday/pull/21) ([github-actions[bot]](https://github.com/apps/github-actions))
- 0.1.3に変更 [\#20](https://github.com/shimakaze-git/django-jp-birthday/pull/20) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop to Master. [\#18](https://github.com/shimakaze-git/django-jp-birthday/pull/18) ([shimakaze-git](https://github.com/shimakaze-git))
- refactor: プルリク先をreleaseに変更. [\#16](https://github.com/shimakaze-git/django-jp-birthday/pull/16) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop to Master [\#15](https://github.com/shimakaze-git/django-jp-birthday/pull/15) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop [\#14](https://github.com/shimakaze-git/django-jp-birthday/pull/14) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: ワークフローの環境変数を色々表示させる. [\#12](https://github.com/shimakaze-git/django-jp-birthday/pull/12) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: master-prを修正する. [\#11](https://github.com/shimakaze-git/django-jp-birthday/pull/11) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: ci周りとreleaseのブランチを変更. [\#10](https://github.com/shimakaze-git/django-jp-birthday/pull/10) ([shimakaze-git](https://github.com/shimakaze-git))
- feat: ciを追加して整備する. [\#9](https://github.com/shimakaze-git/django-jp-birthday/pull/9) ([shimakaze-git](https://github.com/shimakaze-git))
- release 0.1 [\#8](https://github.com/shimakaze-git/django-jp-birthday/pull/8) ([shimakaze-git](https://github.com/shimakaze-git))
- 一度templateを取り込む. [\#2](https://github.com/shimakaze-git/django-jp-birthday/pull/2) ([shimakaze-git](https://github.com/shimakaze-git))

HISTORY
=======

[Unreleased](https://github.com/shimakaze-git/django-jp-birthday/tree/HEAD)
---------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.2.0...HEAD)

**Merged pull requests:**

-   v0.1.5
    [\#37](https://github.com/shimakaze-git/django-jp-birthday/pull/37)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: git pushの処理を追加.
    [\#36](https://github.com/shimakaze-git/django-jp-birthday/pull/36)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.2.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.2.0) (2022-02-07)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.5...v0.2.0)

**Closed issues:**

-   Initial Update
    [\#30](https://github.com/shimakaze-git/django-jp-birthday/issues/30)

[v0.1.5](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.5) (2022-01-29)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

-   v0.1.5
    [\#35](https://github.com/shimakaze-git/django-jp-birthday/pull/35)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master.
    [\#34](https://github.com/shimakaze-git/django-jp-birthday/pull/34)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.1.4](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.4) (2022-01-29)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

-   v0.1.4
    [\#33](https://github.com/shimakaze-git/django-jp-birthday/pull/33)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   0.1.4にバージョンアップ.
    [\#32](https://github.com/shimakaze-git/django-jp-birthday/pull/32)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Config file for pyup.io
    [\#31](https://github.com/shimakaze-git/django-jp-birthday/pull/31)
    ([pyup-bot](https://github.com/pyup-bot))
-   v0.1.3
    [\#29](https://github.com/shimakaze-git/django-jp-birthday/pull/29)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: templateを修正していく.
    [\#28](https://github.com/shimakaze-git/django-jp-birthday/pull/28)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   \[v0.1.3\] (2022-01-29)
    [\#27](https://github.com/shimakaze-git/django-jp-birthday/pull/27)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: add HISTORY.rstを削除していく.
    [\#26](https://github.com/shimakaze-git/django-jp-birthday/pull/26)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   \[v0.1.3\] (2022-01-29)
    [\#25](https://github.com/shimakaze-git/django-jp-birthday/pull/25)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master
    [\#24](https://github.com/shimakaze-git/django-jp-birthday/pull/24)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.1.3](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.3) (2022-01-28)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/515815cbe454ff9b0caf506429079c329f91a11e...v0.1.3)

**Merged pull requests:**

-   v0.1.3
    [\#23](https://github.com/shimakaze-git/django-jp-birthday/pull/23)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master.
    [\#22](https://github.com/shimakaze-git/django-jp-birthday/pull/22)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   v0.1.3
    [\#21](https://github.com/shimakaze-git/django-jp-birthday/pull/21)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   0.1.3に変更
    [\#20](https://github.com/shimakaze-git/django-jp-birthday/pull/20)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop to Master.
    [\#18](https://github.com/shimakaze-git/django-jp-birthday/pull/18)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   refactor: プルリク先をreleaseに変更.
    [\#16](https://github.com/shimakaze-git/django-jp-birthday/pull/16)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop to Master
    [\#15](https://github.com/shimakaze-git/django-jp-birthday/pull/15)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop
    [\#14](https://github.com/shimakaze-git/django-jp-birthday/pull/14)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: ワークフローの環境変数を色々表示させる.
    [\#12](https://github.com/shimakaze-git/django-jp-birthday/pull/12)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: master-prを修正する.
    [\#11](https://github.com/shimakaze-git/django-jp-birthday/pull/11)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: ci周りとreleaseのブランチを変更.
    [\#10](https://github.com/shimakaze-git/django-jp-birthday/pull/10)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   feat: ciを追加して整備する.
    [\#9](https://github.com/shimakaze-git/django-jp-birthday/pull/9)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   release 0.1
    [\#8](https://github.com/shimakaze-git/django-jp-birthday/pull/8)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   一度templateを取り込む.
    [\#2](https://github.com/shimakaze-git/django-jp-birthday/pull/2)
    ([shimakaze-git](https://github.com/shimakaze-git))

\* *This Changelog was automatically generated
by*[github\_changelog\_generator](https://github.com/github-changelog-generator/github-changelog-generator)


\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> django_jp_birthday-0.6.0.tar.gz: django_jp_birthday-0.6.0/HISTORY.md <==
# HISTORY

## [Unreleased](https://github.com/shimakaze-git/django-jp-birthday/tree/HEAD)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.4.0...HEAD)

**Merged pull requests:**

- 干支を表示する機能を作成. [\#45](https://github.com/shimakaze-git/django-jp-birthday/pull/45) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.4.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.4.0) (2022-02-08)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.3.0...v0.4.0)

## [v0.3.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.3.0) (2022-02-07)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.2.0...v0.3.0)

## [v0.2.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.2.0) (2022-02-07)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.5...v0.2.0)

**Closed issues:**

- Initial Update [\#30](https://github.com/shimakaze-git/django-jp-birthday/issues/30)

**Merged pull requests:**

- v0.2.0 [\#40](https://github.com/shimakaze-git/django-jp-birthday/pull/40) ([github-actions[bot]](https://github.com/apps/github-actions))
- Versionを0.2にアップロード. [\#39](https://github.com/shimakaze-git/django-jp-birthday/pull/39) ([shimakaze-git](https://github.com/shimakaze-git))
- v0.1.5 [\#37](https://github.com/shimakaze-git/django-jp-birthday/pull/37) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: git pushの処理を追加. [\#36](https://github.com/shimakaze-git/django-jp-birthday/pull/36) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.5](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.5) (2022-01-29)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

- v0.1.5 [\#35](https://github.com/shimakaze-git/django-jp-birthday/pull/35) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master. [\#34](https://github.com/shimakaze-git/django-jp-birthday/pull/34) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.4](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.4) (2022-01-29)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

- v0.1.4 [\#33](https://github.com/shimakaze-git/django-jp-birthday/pull/33) ([github-actions[bot]](https://github.com/apps/github-actions))
- 0.1.4にバージョンアップ. [\#32](https://github.com/shimakaze-git/django-jp-birthday/pull/32) ([shimakaze-git](https://github.com/shimakaze-git))
- Config file for pyup.io [\#31](https://github.com/shimakaze-git/django-jp-birthday/pull/31) ([pyup-bot](https://github.com/pyup-bot))
- v0.1.3 [\#29](https://github.com/shimakaze-git/django-jp-birthday/pull/29) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: templateを修正していく. [\#28](https://github.com/shimakaze-git/django-jp-birthday/pull/28) ([shimakaze-git](https://github.com/shimakaze-git))
- \[v0.1.3\] \(2022-01-29\) [\#27](https://github.com/shimakaze-git/django-jp-birthday/pull/27) ([github-actions[bot]](https://github.com/apps/github-actions))
- fix: add HISTORY.rstを削除していく. [\#26](https://github.com/shimakaze-git/django-jp-birthday/pull/26) ([shimakaze-git](https://github.com/shimakaze-git))
- \[v0.1.3\] \(2022-01-29\) [\#25](https://github.com/shimakaze-git/django-jp-birthday/pull/25) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master [\#24](https://github.com/shimakaze-git/django-jp-birthday/pull/24) ([shimakaze-git](https://github.com/shimakaze-git))

## [v0.1.3](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.3) (2022-01-28)

[Full Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/515815cbe454ff9b0caf506429079c329f91a11e...v0.1.3)

**Merged pull requests:**

- v0.1.3 [\#23](https://github.com/shimakaze-git/django-jp-birthday/pull/23) ([github-actions[bot]](https://github.com/apps/github-actions))
- develop to master. [\#22](https://github.com/shimakaze-git/django-jp-birthday/pull/22) ([shimakaze-git](https://github.com/shimakaze-git))
- v0.1.3 [\#21](https://github.com/shimakaze-git/django-jp-birthday/pull/21) ([github-actions[bot]](https://github.com/apps/github-actions))
- 0.1.3に変更 [\#20](https://github.com/shimakaze-git/django-jp-birthday/pull/20) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop to Master. [\#18](https://github.com/shimakaze-git/django-jp-birthday/pull/18) ([shimakaze-git](https://github.com/shimakaze-git))
- refactor: プルリク先をreleaseに変更. [\#16](https://github.com/shimakaze-git/django-jp-birthday/pull/16) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop to Master [\#15](https://github.com/shimakaze-git/django-jp-birthday/pull/15) ([shimakaze-git](https://github.com/shimakaze-git))
- Develop [\#14](https://github.com/shimakaze-git/django-jp-birthday/pull/14) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: ワークフローの環境変数を色々表示させる. [\#12](https://github.com/shimakaze-git/django-jp-birthday/pull/12) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: master-prを修正する. [\#11](https://github.com/shimakaze-git/django-jp-birthday/pull/11) ([shimakaze-git](https://github.com/shimakaze-git))
- fix: ci周りとreleaseのブランチを変更. [\#10](https://github.com/shimakaze-git/django-jp-birthday/pull/10) ([shimakaze-git](https://github.com/shimakaze-git))
- feat: ciを追加して整備する. [\#9](https://github.com/shimakaze-git/django-jp-birthday/pull/9) ([shimakaze-git](https://github.com/shimakaze-git))
- release 0.1 [\#8](https://github.com/shimakaze-git/django-jp-birthday/pull/8) ([shimakaze-git](https://github.com/shimakaze-git))
- 一度templateを取り込む. [\#2](https://github.com/shimakaze-git/django-jp-birthday/pull/2) ([shimakaze-git](https://github.com/shimakaze-git))

HISTORY
=======

[Unreleased](https://github.com/shimakaze-git/django-jp-birthday/tree/HEAD)
---------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.2.0...HEAD)

**Merged pull requests:**

-   v0.1.5
    [\#37](https://github.com/shimakaze-git/django-jp-birthday/pull/37)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: git pushの処理を追加.
    [\#36](https://github.com/shimakaze-git/django-jp-birthday/pull/36)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.2.0](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.2.0) (2022-02-07)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.5...v0.2.0)

**Closed issues:**

-   Initial Update
    [\#30](https://github.com/shimakaze-git/django-jp-birthday/issues/30)

[v0.1.5](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.5) (2022-01-29)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

-   v0.1.5
    [\#35](https://github.com/shimakaze-git/django-jp-birthday/pull/35)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master.
    [\#34](https://github.com/shimakaze-git/django-jp-birthday/pull/34)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.1.4](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.4) (2022-01-29)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

-   v0.1.4
    [\#33](https://github.com/shimakaze-git/django-jp-birthday/pull/33)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   0.1.4にバージョンアップ.
    [\#32](https://github.com/shimakaze-git/django-jp-birthday/pull/32)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Config file for pyup.io
    [\#31](https://github.com/shimakaze-git/django-jp-birthday/pull/31)
    ([pyup-bot](https://github.com/pyup-bot))
-   v0.1.3
    [\#29](https://github.com/shimakaze-git/django-jp-birthday/pull/29)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: templateを修正していく.
    [\#28](https://github.com/shimakaze-git/django-jp-birthday/pull/28)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   \[v0.1.3\] (2022-01-29)
    [\#27](https://github.com/shimakaze-git/django-jp-birthday/pull/27)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   fix: add HISTORY.rstを削除していく.
    [\#26](https://github.com/shimakaze-git/django-jp-birthday/pull/26)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   \[v0.1.3\] (2022-01-29)
    [\#25](https://github.com/shimakaze-git/django-jp-birthday/pull/25)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master
    [\#24](https://github.com/shimakaze-git/django-jp-birthday/pull/24)
    ([shimakaze-git](https://github.com/shimakaze-git))

[v0.1.3](https://github.com/shimakaze-git/django-jp-birthday/tree/v0.1.3) (2022-01-28)
--------------------------------------------------------------------------------------

[Full
Changelog](https://github.com/shimakaze-git/django-jp-birthday/compare/515815cbe454ff9b0caf506429079c329f91a11e...v0.1.3)

**Merged pull requests:**

-   v0.1.3
    [\#23](https://github.com/shimakaze-git/django-jp-birthday/pull/23)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   develop to master.
    [\#22](https://github.com/shimakaze-git/django-jp-birthday/pull/22)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   v0.1.3
    [\#21](https://github.com/shimakaze-git/django-jp-birthday/pull/21)
    ([github-actions\[bot\]](https://github.com/apps/github-actions))
-   0.1.3に変更
    [\#20](https://github.com/shimakaze-git/django-jp-birthday/pull/20)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop to Master.
    [\#18](https://github.com/shimakaze-git/django-jp-birthday/pull/18)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   refactor: プルリク先をreleaseに変更.
    [\#16](https://github.com/shimakaze-git/django-jp-birthday/pull/16)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop to Master
    [\#15](https://github.com/shimakaze-git/django-jp-birthday/pull/15)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   Develop
    [\#14](https://github.com/shimakaze-git/django-jp-birthday/pull/14)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: ワークフローの環境変数を色々表示させる.
    [\#12](https://github.com/shimakaze-git/django-jp-birthday/pull/12)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: master-prを修正する.
    [\#11](https://github.com/shimakaze-git/django-jp-birthday/pull/11)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   fix: ci周りとreleaseのブランチを変更.
    [\#10](https://github.com/shimakaze-git/django-jp-birthday/pull/10)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   feat: ciを追加して整備する.
    [\#9](https://github.com/shimakaze-git/django-jp-birthday/pull/9)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   release 0.1
    [\#8](https://github.com/shimakaze-git/django-jp-birthday/pull/8)
    ([shimakaze-git](https://github.com/shimakaze-git))
-   一度templateを取り込む.
    [\#2](https://github.com/shimakaze-git/django-jp-birthday/pull/2)
    ([shimakaze-git](https://github.com/shimakaze-git))

\* *This Changelog was automatically generated
by*[github\_changelog\_generator](https://github.com/github-changelog-generator/github-changelog-generator)


\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
